package
Version:
v0.0.0-...-9b343ff
Opens a new window with list of versions in this module.
Published: Oct 16, 2024
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type BgmUserCollection struct {
UserID string `sql:"primary_key"`
SubjectID string `sql:"primary_key"`
SubjectType *int64
CollectionType *int64
CollectedTime *time.Time
Rating *int64
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.