table

package
v0.0.0-...-9b343ff Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 16, 2024 License: MIT Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var BgmUser = newBgmUserTable("public", "bgm_user", "")
var BgmUserCollection = newBgmUserCollectionTable("public", "bgm_user_collection", "")

Functions

func UseSchema

func UseSchema(schema string)

UseSchema sets a new schema name for all generated table SQL builder types. It is recommended to invoke this method only once at the beginning of the program.

Types

type BgmUserCollectionTable

type BgmUserCollectionTable struct {
	EXCLUDED bgmUserCollectionTable
	// contains filtered or unexported fields
}

func (BgmUserCollectionTable) AS

AS creates new BgmUserCollectionTable with assigned alias

func (BgmUserCollectionTable) FromSchema

func (a BgmUserCollectionTable) FromSchema(schemaName string) *BgmUserCollectionTable

Schema creates new BgmUserCollectionTable with assigned schema name

func (BgmUserCollectionTable) WithPrefix

WithPrefix creates new BgmUserCollectionTable with assigned table prefix

func (BgmUserCollectionTable) WithSuffix

WithSuffix creates new BgmUserCollectionTable with assigned table suffix

type BgmUserTable

type BgmUserTable struct {
	EXCLUDED bgmUserTable
	// contains filtered or unexported fields
}

func (BgmUserTable) AS

func (a BgmUserTable) AS(alias string) *BgmUserTable

AS creates new BgmUserTable with assigned alias

func (BgmUserTable) FromSchema

func (a BgmUserTable) FromSchema(schemaName string) *BgmUserTable

Schema creates new BgmUserTable with assigned schema name

func (BgmUserTable) WithPrefix

func (a BgmUserTable) WithPrefix(prefix string) *BgmUserTable

WithPrefix creates new BgmUserTable with assigned table prefix

func (BgmUserTable) WithSuffix

func (a BgmUserTable) WithSuffix(suffix string) *BgmUserTable

WithSuffix creates new BgmUserTable with assigned table suffix

Jump to